pub struct OperationSpec {Show 16 fields
pub method: Method,
pub path: String,
pub operation_id: Option<String>,
pub summary: Option<String>,
pub description: Option<String>,
pub tags: Vec<String>,
pub params: Vec<ParamSpec>,
pub request_body: Option<RequestBodySpec>,
pub responses: Vec<ResponseSpec>,
pub handler_id: String,
pub authenticated: bool,
pub is_public: bool,
pub rate_limit: Option<RateLimitSpec>,
pub allowed_request_content_types: Option<Vec<&'static str>>,
pub vendor_extensions: VendorExtensions,
pub license_requirement: Option<LicenseReqSpec>,
}Expand description
Simplified operation specification for the type-safe builder
Fields
method: Methodpath: Stringoperation_id: Option<String>summary: Option<String>description: Option<String>params: Vec<ParamSpec>request_body: Option<RequestBodySpec>responses: Vec<ResponseSpec>handler_id: StringInternal handler id; can be used by registry/generator to map a handler identity
authenticated: boolWhether this operation requires authentication.
true = authenticated endpoint, false = public endpoint.
is_public: boolExplicitly mark route as public (no auth required)
rate_limit: Option<RateLimitSpec>Optional rate & concurrency limits for this operation
allowed_request_content_types: Option<Vec<&'static str>>Optional whitelist of allowed request Content-Type values (without parameters). Example: Some(vec![“application/json”, “multipart/form-data”, “application/pdf”]) When set, gateway middleware will enforce these types and return HTTP 415 for requests with disallowed Content-Type headers. This is independent of the request body schema and should not be used to create synthetic request bodies.
vendor_extensions: VendorExtensionsOpenAPI vendor extensions (x-*)
license_requirement: Option<LicenseReqSpec>Trait Implementations
Sourceimpl Clone for OperationSpec
impl Clone for OperationSpec
Sourcefn clone(&self) -> OperationSpec
fn clone(&self) -> OperationSpec
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreAuto Trait Implementations
impl Freeze for OperationSpec
impl RefUnwindSafe for OperationSpec
impl Send for OperationSpec
impl Sync for OperationSpec
impl Unpin for OperationSpec
impl UnsafeUnpin for OperationSpec
impl UnwindSafe for OperationSpec