pub trait IntoResponse {
// Required method
fn into_response(self) -> Response<Body>;
}Expand description
Trait for generating responses.
Types that implement IntoResponse can be returned from handlers.
Implementing IntoResponse
You generally shouldn’t have to implement IntoResponse manually, as axum
provides implementations for many common types.
However it might be necessary if you have a custom error type that you want to return from handlers:
use axum::{
Router,
body::{self, Bytes},
routing::get,
http::StatusCode,
response::{IntoResponse, Response},
};
enum MyError {
SomethingWentWrong,
SomethingElseWentWrong,
}
impl IntoResponse for MyError {
fn into_response(self) -> Response {
let body = match self {
MyError::SomethingWentWrong => "something went wrong",
MyError::SomethingElseWentWrong => "something else went wrong",
};
// it's often easiest to implement `IntoResponse` by calling other implementations
(StatusCode::INTERNAL_SERVER_ERROR, body).into_response()
}
}
// `Result<impl IntoResponse, MyError>` can now be returned from handlers
let app = Router::new().route("/", get(handler));
async fn handler() -> Result<(), MyError> {
Err(MyError::SomethingWentWrong)
}Or if you have a custom body type you’ll also need to implement
IntoResponse for it:
use axum::{
body,
routing::get,
response::{IntoResponse, Response},
body::Body,
Router,
};
use http::HeaderMap;
use bytes::Bytes;
use http_body::Frame;
use std::{
convert::Infallible,
task::{Poll, Context},
pin::Pin,
};
struct MyBody;
// First implement `Body` for `MyBody`. This could for example use
// some custom streaming protocol.
impl http_body::Body for MyBody {
type Data = Bytes;
type Error = Infallible;
fn poll_frame(
self: Pin<&mut Self>,
cx: &mut Context<'_>,
) -> Poll<Option<Result<Frame<Self::Data>, Self::Error>>> {
// ...
}
}
// Now we can implement `IntoResponse` directly for `MyBody`
impl IntoResponse for MyBody {
fn into_response(self) -> Response {
Response::new(Body::new(self))
}
}
// `MyBody` can now be returned from handlers.
let app = Router::new().route("/", get(|| async { MyBody }));Required Methods
Sourcefn into_response(self) -> Response<Body>
fn into_response(self) -> Response<Body>
Create a response.
Implementations on Foreign Types
Sourceimpl IntoResponse for &'static str
impl IntoResponse for &'static str
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for &'static [u8]
impl IntoResponse for &'static [u8]
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for Cow<'static, str>
impl IntoResponse for Cow<'static, str>
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for Cow<'static, [u8]>
impl IntoResponse for Cow<'static, [u8]>
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for Infallible
impl IntoResponse for Infallible
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for ExtensionRejection
impl IntoResponse for ExtensionRejection
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for FormRejection
impl IntoResponse for FormRejection
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for JsonRejection
impl IntoResponse for JsonRejection
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for MatchedPathRejection
impl IntoResponse for MatchedPathRejection
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for PathRejection
impl IntoResponse for PathRejection
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for QueryRejection
impl IntoResponse for QueryRejection
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for RawFormRejection
impl IntoResponse for RawFormRejection
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for RawPathParamsRejection
impl IntoResponse for RawPathParamsRejection
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for ()
impl IntoResponse for ()
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for Box<str>
impl IntoResponse for Box<str>
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for Box<[u8]>
impl IntoResponse for Box<[u8]>
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for String
impl IntoResponse for String
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for Vec<u8>
impl IntoResponse for Vec<u8>
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for FailedToDeserializePathParams
impl IntoResponse for FailedToDeserializePathParams
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for InvalidUtf8InPathParam
impl IntoResponse for InvalidUtf8InPathParam
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for FailedToDeserializeForm
impl IntoResponse for FailedToDeserializeForm
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for FailedToDeserializeFormBody
impl IntoResponse for FailedToDeserializeFormBody
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for FailedToDeserializeQueryString
impl IntoResponse for FailedToDeserializeQueryString
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for InvalidFormContentType
impl IntoResponse for InvalidFormContentType
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for JsonDataError
impl IntoResponse for JsonDataError
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for JsonSyntaxError
impl IntoResponse for JsonSyntaxError
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for MatchedPathMissing
impl IntoResponse for MatchedPathMissing
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for MissingExtension
impl IntoResponse for MissingExtension
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for MissingJsonContentType
impl IntoResponse for MissingJsonContentType
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for MissingPathParams
impl IntoResponse for MissingPathParams
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for NestedPathRejection
impl IntoResponse for NestedPathRejection
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for Redirect
impl IntoResponse for Redirect
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for NoContent
impl IntoResponse for NoContent
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for Bytes
impl IntoResponse for Bytes
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for BytesMut
impl IntoResponse for BytesMut
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for Extensions
impl IntoResponse for Extensions
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for HeaderMap
impl IntoResponse for HeaderMap
fn into_response(self) -> Response<Body>
Sourceimpl IntoResponse for Parts
impl IntoResponse for Parts
fn into_response(self) -> Response<Body>
Sourceimpl<B> IntoResponse for Response<B>
impl<B> IntoResponse for Response<B>
fn into_response(self) -> Response<Body>
Sourceimpl<K, V, const N: usize> IntoResponse for [(K, V); N]where
K: TryInto<HeaderName>,
<K as TryInto<HeaderName>>::Error: Display,
V: TryInto<HeaderValue>,
<V as TryInto<HeaderValue>>::Error: Display,
impl<K, V, const N: usize> IntoResponse for [(K, V); N]where
K: TryInto<HeaderName>,
<K as TryInto<HeaderName>>::Error: Display,
V: TryInto<HeaderValue>,
<V as TryInto<HeaderValue>>::Error: Display,
fn into_response(self) -> Response<Body>
Sourceimpl<R> IntoResponse for (Parts, R)where
R: IntoResponse,
impl<R> IntoResponse for (Parts, R)where
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R> IntoResponse for (Response<()>, R)where
R: IntoResponse,
impl<R> IntoResponse for (Response<()>, R)where
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R> IntoResponse for (StatusCode, R)where
R: IntoResponse,
impl<R> IntoResponse for (StatusCode, R)where
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R> IntoResponse for (R,)where
R: IntoResponse,
impl<R> IntoResponse for (R,)where
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1> IntoResponse for (Parts, T1, R)where
T1: IntoResponseParts,
R: IntoResponse,
impl<R, T1> IntoResponse for (Parts, T1, R)where
T1: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1> IntoResponse for (Response<()>, T1, R)where
T1: IntoResponseParts,
R: IntoResponse,
impl<R, T1> IntoResponse for (Response<()>, T1, R)where
T1: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1> IntoResponse for (StatusCode, T1, R)where
T1: IntoResponseParts,
R: IntoResponse,
impl<R, T1> IntoResponse for (StatusCode, T1, R)where
T1: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1> IntoResponse for (T1, R)where
T1: IntoResponseParts,
R: IntoResponse,
impl<R, T1> IntoResponse for (T1, R)where
T1: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2> IntoResponse for (Parts, T1, T2, R)
impl<R, T1, T2> IntoResponse for (Parts, T1, T2, R)
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2> IntoResponse for (Response<()>, T1, T2, R)
impl<R, T1, T2> IntoResponse for (Response<()>, T1, T2, R)
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2> IntoResponse for (StatusCode, T1, T2, R)
impl<R, T1, T2> IntoResponse for (StatusCode, T1, T2, R)
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2> IntoResponse for (T1, T2, R)
impl<R, T1, T2> IntoResponse for (T1, T2, R)
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3> IntoResponse for (Parts, T1, T2, T3, R)
impl<R, T1, T2, T3> IntoResponse for (Parts, T1, T2, T3, R)
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3> IntoResponse for (Response<()>, T1, T2, T3, R)
impl<R, T1, T2, T3> IntoResponse for (Response<()>, T1, T2, T3, R)
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3> IntoResponse for (StatusCode, T1, T2, T3, R)
impl<R, T1, T2, T3> IntoResponse for (StatusCode, T1, T2, T3, R)
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3> IntoResponse for (T1, T2, T3, R)
impl<R, T1, T2, T3> IntoResponse for (T1, T2, T3, R)
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4> IntoResponse for (Parts, T1, T2, T3, T4, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4> IntoResponse for (Parts, T1, T2, T3, T4, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4> IntoResponse for (Response<()>, T1, T2, T3, T4, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4> IntoResponse for (Response<()>, T1, T2, T3, T4, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4> IntoResponse for (StatusCode, T1, T2, T3, T4, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4> IntoResponse for (StatusCode, T1, T2, T3, T4, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4> IntoResponse for (T1, T2, T3, T4, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4> IntoResponse for (T1, T2, T3, T4, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5> IntoResponse for (Parts, T1, T2, T3, T4, T5, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5> IntoResponse for (Parts, T1, T2, T3, T4, T5, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5> IntoResponse for (Response<()>, T1, T2, T3, T4, T5, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5> IntoResponse for (Response<()>, T1, T2, T3, T4, T5, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5> IntoResponse for (StatusCode, T1, T2, T3, T4, T5, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5> IntoResponse for (StatusCode, T1, T2, T3, T4, T5, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5> IntoResponse for (T1, T2, T3, T4, T5, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5> IntoResponse for (T1, T2, T3, T4, T5, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6> IntoResponse for (Parts, T1, T2, T3, T4, T5, T6, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6> IntoResponse for (Parts, T1, T2, T3, T4, T5, T6, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6> IntoResponse for (Response<()>, T1, T2, T3, T4, T5, T6, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6> IntoResponse for (Response<()>, T1, T2, T3, T4, T5, T6, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6> IntoResponse for (StatusCode, T1, T2, T3, T4, T5, T6, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6> IntoResponse for (StatusCode, T1, T2, T3, T4, T5, T6, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6> IntoResponse for (T1, T2, T3, T4, T5, T6, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6> IntoResponse for (T1, T2, T3, T4, T5, T6, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7> IntoResponse for (Parts, T1, T2, T3, T4, T5, T6, T7, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7> IntoResponse for (Parts, T1, T2, T3, T4, T5, T6, T7, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7> IntoResponse for (Response<()>, T1, T2, T3, T4, T5, T6, T7, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7> IntoResponse for (Response<()>, T1, T2, T3, T4, T5, T6, T7, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7> IntoResponse for (StatusCode, T1, T2, T3, T4, T5, T6, T7, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7> IntoResponse for (StatusCode, T1, T2, T3, T4, T5, T6, T7, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7> IntoResponse for (T1, T2, T3, T4, T5, T6, T7, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7> IntoResponse for (T1, T2, T3, T4, T5, T6, T7, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8> IntoResponse for (Parts, T1, T2, T3, T4, T5, T6, T7, T8, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8> IntoResponse for (Parts, T1, T2, T3, T4, T5, T6, T7, T8, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8> IntoResponse for (Response<()>, T1, T2, T3, T4, T5, T6, T7, T8, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8> IntoResponse for (Response<()>, T1, T2, T3, T4, T5, T6, T7, T8, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8> IntoResponse for (StatusCode, T1, T2, T3, T4, T5, T6, T7, T8, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8> IntoResponse for (StatusCode, T1, T2, T3, T4, T5, T6, T7, T8, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8> IntoResponse for (T1, T2, T3, T4, T5, T6, T7, T8, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8> IntoResponse for (T1, T2, T3, T4, T5, T6, T7, T8, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9> IntoResponse for (Parts, T1, T2, T3, T4, T5, T6, T7, T8, T9, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9> IntoResponse for (Parts, T1, T2, T3, T4, T5, T6, T7, T8, T9, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9> IntoResponse for (Response<()>, T1, T2, T3, T4, T5, T6, T7, T8, T9, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9> IntoResponse for (Response<()>, T1, T2, T3, T4, T5, T6, T7, T8, T9, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9> IntoResponse for (StatusCode, T1, T2, T3, T4, T5, T6, T7, T8, T9, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9> IntoResponse for (StatusCode, T1, T2, T3, T4, T5, T6, T7, T8, T9, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9> IntoResponse for (T1, T2, T3, T4, T5, T6, T7, T8, T9, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9> IntoResponse for (T1, T2, T3, T4, T5, T6, T7, T8, T9, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> IntoResponse for (Parts, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> IntoResponse for (Parts, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> IntoResponse for (Response<()>, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> IntoResponse for (Response<()>, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> IntoResponse for (StatusCode, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> IntoResponse for (StatusCode, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> IntoResponse for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> IntoResponse for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> IntoResponse for (Parts, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> IntoResponse for (Parts, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> IntoResponse for (Response<()>, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> IntoResponse for (Response<()>, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> IntoResponse for (StatusCode, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> IntoResponse for (StatusCode, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> IntoResponse for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> IntoResponse for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12> IntoResponse for (Parts, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12> IntoResponse for (Parts, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12> IntoResponse for (Response<()>, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12> IntoResponse for (Response<()>, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12> IntoResponse for (StatusCode, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12> IntoResponse for (StatusCode, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12> IntoResponse for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12> IntoResponse for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13> IntoResponse for (Parts, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
T13: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13> IntoResponse for (Parts, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
T13: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13> IntoResponse for (Response<()>, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
T13: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13> IntoResponse for (Response<()>, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
T13: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13> IntoResponse for (StatusCode, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
T13: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13> IntoResponse for (StatusCode, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
T13: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13> IntoResponse for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
T13: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13> IntoResponse for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
T13: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14> IntoResponse for (Parts, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
T13: IntoResponseParts,
T14: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14> IntoResponse for (Parts, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
T13: IntoResponseParts,
T14: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14> IntoResponse for (Response<()>, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
T13: IntoResponseParts,
T14: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14> IntoResponse for (Response<()>, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
T13: IntoResponseParts,
T14: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14> IntoResponse for (StatusCode, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
T13: IntoResponseParts,
T14: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14> IntoResponse for (StatusCode, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
T13: IntoResponseParts,
T14: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14> IntoResponse for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
T13: IntoResponseParts,
T14: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14> IntoResponse for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
T13: IntoResponseParts,
T14: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> IntoResponse for (Parts, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
T13: IntoResponseParts,
T14: IntoResponseParts,
T15: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> IntoResponse for (Parts, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
T13: IntoResponseParts,
T14: IntoResponseParts,
T15: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> IntoResponse for (Response<()>, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
T13: IntoResponseParts,
T14: IntoResponseParts,
T15: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> IntoResponse for (Response<()>, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
T13: IntoResponseParts,
T14: IntoResponseParts,
T15: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> IntoResponse for (StatusCode, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
T13: IntoResponseParts,
T14: IntoResponseParts,
T15: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> IntoResponse for (StatusCode, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
T13: IntoResponseParts,
T14: IntoResponseParts,
T15: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> IntoResponse for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
T13: IntoResponseParts,
T14: IntoResponseParts,
T15: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> IntoResponse for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
T13: IntoResponseParts,
T14: IntoResponseParts,
T15: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16> IntoResponse for (Parts, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
T13: IntoResponseParts,
T14: IntoResponseParts,
T15: IntoResponseParts,
T16: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16> IntoResponse for (Parts, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
T13: IntoResponseParts,
T14: IntoResponseParts,
T15: IntoResponseParts,
T16: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16> IntoResponse for (Response<()>, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
T13: IntoResponseParts,
T14: IntoResponseParts,
T15: IntoResponseParts,
T16: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16> IntoResponse for (Response<()>, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
T13: IntoResponseParts,
T14: IntoResponseParts,
T15: IntoResponseParts,
T16: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16> IntoResponse for (StatusCode, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
T13: IntoResponseParts,
T14: IntoResponseParts,
T15: IntoResponseParts,
T16: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16> IntoResponse for (StatusCode, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
T13: IntoResponseParts,
T14: IntoResponseParts,
T15: IntoResponseParts,
T16: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16> IntoResponse for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
T13: IntoResponseParts,
T14: IntoResponseParts,
T15: IntoResponseParts,
T16: IntoResponseParts,
R: IntoResponse,
impl<R, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16> IntoResponse for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, R)where
T1: IntoResponseParts,
T2: IntoResponseParts,
T3: IntoResponseParts,
T4: IntoResponseParts,
T5: IntoResponseParts,
T6: IntoResponseParts,
T7: IntoResponseParts,
T8: IntoResponseParts,
T9: IntoResponseParts,
T10: IntoResponseParts,
T11: IntoResponseParts,
T12: IntoResponseParts,
T13: IntoResponseParts,
T14: IntoResponseParts,
T15: IntoResponseParts,
T16: IntoResponseParts,
R: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<S, E> IntoResponse for Sse<S>
impl<S, E> IntoResponse for Sse<S>
fn into_response(self) -> Response<Body>
Sourceimpl<T> IntoResponse for Result<T, ErrorResponse>where
T: IntoResponse,
impl<T> IntoResponse for Result<T, ErrorResponse>where
T: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<T> IntoResponse for Extension<T>
impl<T> IntoResponse for Extension<T>
fn into_response(self) -> Response<Body>
Sourceimpl<T> IntoResponse for Form<T>where
T: Serialize,
impl<T> IntoResponse for Form<T>where
T: Serialize,
fn into_response(self) -> Response<Body>
Sourceimpl<T> IntoResponse for Html<T>where
T: IntoResponse,
impl<T> IntoResponse for Html<T>where
T: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<T, E> IntoResponse for Result<T, E>where
T: IntoResponse,
E: IntoResponse,
impl<T, E> IntoResponse for Result<T, E>where
T: IntoResponse,
E: IntoResponse,
fn into_response(self) -> Response<Body>
Sourceimpl<T, U> IntoResponse for Chain<T, U>
impl<T, U> IntoResponse for Chain<T, U>
fn into_response(self) -> Response<Body>
Sourceimpl<const N: usize> IntoResponse for &'static [u8; N]
impl<const N: usize> IntoResponse for &'static [u8; N]
fn into_response(self) -> Response<Body>
Implementors
impl IntoResponse for BytesRejection
impl IntoResponse for FailedToBufferBody
impl IntoResponse for StringRejection
impl IntoResponse for Problem
Available on crate feature
axum only.Axum integration: make Problem directly usable as a response.
Automatically enriches the Problem with trace_id from the current
tracing span if not already set.