Module select

Module select 

Field projection support for $select OData queries.

This module provides utilities for projecting DTOs based on selected fields. It allows handlers to filter response objects to only include requested fields.

Functions

apply_select
Helper function to apply field projection to a serializable value.
page_to_projected_json
Convert a page of items to a page of projected JSON values.
project_json
Project a JSON value to only include selected fields.