#[module]Expand description
Main #[module] attribute macro
ctor must be a Rust expression that evaluates to the module instance,
e.g. ctor = MyModule::new() or ctor = Default::default().
#[module]Main #[module] attribute macro
ctor must be a Rust expression that evaluates to the module instance,
e.g. ctor = MyModule::new() or ctor = Default::default().