Module backends

Module backends 

Backend abstraction for out-of-process module management

This module provides traits and types for spawning and managing OoP module instances.

Re-exports

pub use local::LocalProcessBackend;

Modules

local
Local process backend implementation
log_forwarder
Log forwarding for OoP module stdout/stderr

Structs

InstanceHandle
A handle to a running module instance
OopModuleConfig
Configuration for an out-of-process module
OopSpawnConfig
Configuration passed to OopBackend::spawn

Enums

BackendKind
The kind of backend used to spawn and manage module instances

Traits

ModuleRuntimeBackend
Trait for backends that can spawn and manage module instances
OopBackend
A type-erased backend for spawning OoP modules.