Module runtime

Module runtime 

Modules

shutdown
Shutdown signal handling utilities

Structs

ClientRegistration
A type-erased client registration for injecting clients into the ClientHub.
Endpoint
Represents an endpoint where a module instance can be reached
GrpcInstallerData
Grouped installers for all modules in the process.
GrpcInstallerStore
Runtime-owned store for gRPC service installers.
HostRuntime
HostRuntime owns the lifecycle orchestration for ModKit.
ModuleInstallers
Installers for a specific module (module name + service installers).
ModuleInstance
Represents a single instance of a module
ModuleManager
Central registry that tracks all running module instances in the system. Provides discovery, health tracking, and round-robin load balancing.
OopModuleSpawnConfig
Configuration for a single OoP module to be spawned.
OopSpawnOptions
Options for spawning OoP modules.
RunOptions
Options for running the ModKit runner.
SystemContext
System-level context provided to system modules during the wiring phase.

Enums

DbOptions
How the runtime should provide DBs to modules.
InstanceState
ShutdownOptions
How the runtime should decide when to stop.

Constants

MODKIT_DIRECTORY_ENDPOINT_ENV
Environment variable name for passing directory endpoint to OoP modules.
MODKIT_MODULE_CONFIG_ENV
Environment variable name for passing rendered module config to OoP modules.

Functions

run
Full cycle is orchestrated by HostRuntime (see runtime/host_runtime.rs docs).