Module throttled_log

Module throttled_log 

Lock-free throttled logging helper.

Provides a reusable mechanism to limit log frequency without performing any logging itself.

Structs

ThrottledLog
A lock-free helper that decides whether logging is allowed at the current moment.