#[non_exhaustive]pub enum CanonicalError {
Show 16 variants
#[non_exhaustive] Cancelled {
ctx: CancelledV1,
detail: String,
resource_type: Option<String>,
resource_name: Option<String>,
},
#[non_exhaustive] Unknown {
ctx: UnknownV1,
detail: String,
resource_type: Option<String>,
resource_name: Option<String>,
},
#[non_exhaustive] InvalidArgument {
ctx: InvalidArgumentV1,
detail: String,
resource_type: Option<String>,
resource_name: Option<String>,
},
#[non_exhaustive] DeadlineExceeded {
ctx: DeadlineExceededV1,
detail: String,
resource_type: Option<String>,
resource_name: Option<String>,
},
#[non_exhaustive] NotFound {
ctx: NotFoundV1,
detail: String,
resource_type: Option<String>,
resource_name: Option<String>,
},
#[non_exhaustive] AlreadyExists {
ctx: AlreadyExistsV1,
detail: String,
resource_type: Option<String>,
resource_name: Option<String>,
},
#[non_exhaustive] PermissionDenied {
ctx: PermissionDeniedV1,
detail: String,
resource_type: Option<String>,
resource_name: Option<String>,
},
#[non_exhaustive] ResourceExhausted {
ctx: ResourceExhaustedV1,
detail: String,
resource_type: Option<String>,
resource_name: Option<String>,
},
#[non_exhaustive] FailedPrecondition {
ctx: FailedPreconditionV1,
detail: String,
resource_type: Option<String>,
resource_name: Option<String>,
},
#[non_exhaustive] Aborted {
ctx: AbortedV1,
detail: String,
resource_type: Option<String>,
resource_name: Option<String>,
},
#[non_exhaustive] OutOfRange {
ctx: OutOfRangeV1,
detail: String,
resource_type: Option<String>,
resource_name: Option<String>,
},
#[non_exhaustive] Unimplemented {
ctx: UnimplementedV1,
detail: String,
resource_type: Option<String>,
resource_name: Option<String>,
},
#[non_exhaustive] Internal {
ctx: InternalV1,
detail: String,
},
#[non_exhaustive] ServiceUnavailable {
ctx: ServiceUnavailableV1,
detail: String,
resource_type: Option<String>,
resource_name: Option<String>,
},
#[non_exhaustive] DataLoss {
ctx: DataLossV1,
detail: String,
resource_type: Option<String>,
resource_name: Option<String>,
},
#[non_exhaustive] Unauthenticated {
ctx: UnauthenticatedV1,
detail: String,
resource_type: Option<String>,
resource_name: Option<String>,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
#[non_exhaustive]Cancelled
Fields
This variant is marked as non-exhaustive
ctx: CancelledV1#[non_exhaustive]Unknown
Fields
This variant is marked as non-exhaustive
#[non_exhaustive]InvalidArgument
Fields
This variant is marked as non-exhaustive
ctx: InvalidArgumentV1#[non_exhaustive]DeadlineExceeded
Fields
This variant is marked as non-exhaustive
ctx: DeadlineExceededV1#[non_exhaustive]NotFound
Fields
This variant is marked as non-exhaustive
ctx: NotFoundV1#[non_exhaustive]AlreadyExists
Fields
This variant is marked as non-exhaustive
ctx: AlreadyExistsV1#[non_exhaustive]PermissionDenied
Fields
This variant is marked as non-exhaustive
ctx: PermissionDeniedV1#[non_exhaustive]ResourceExhausted
Fields
This variant is marked as non-exhaustive
ctx: ResourceExhaustedV1#[non_exhaustive]FailedPrecondition
Fields
This variant is marked as non-exhaustive
#[non_exhaustive]Aborted
Fields
This variant is marked as non-exhaustive
#[non_exhaustive]OutOfRange
Fields
This variant is marked as non-exhaustive
ctx: OutOfRangeV1#[non_exhaustive]Unimplemented
Fields
This variant is marked as non-exhaustive
ctx: UnimplementedV1#[non_exhaustive]Internal
Fields
This variant is marked as non-exhaustive
ctx: InternalV1#[non_exhaustive]DataLoss
Fields
This variant is marked as non-exhaustive
ctx: DataLossV1#[non_exhaustive]Unauthenticated
Fields
This variant is marked as non-exhaustive
ctx: UnauthenticatedV1Implementations
Sourceimpl CanonicalError
impl CanonicalError
pub fn internal( detail: impl Into<String>, ) -> ResourceErrorBuilder<ResourceAbsent, NoContext>
pub fn unauthenticated() -> ResourceErrorBuilder<ResourceAbsent, NeedsReason>
Sourceimpl CanonicalError
impl CanonicalError
pub fn detail(&self) -> &str
pub fn resource_type(&self) -> Option<&str>
pub fn resource_name(&self) -> Option<&str>
Sourcepub fn diagnostic(&self) -> Option<&str>
pub fn diagnostic(&self) -> Option<&str>
Returns the internal diagnostic string for Internal and Unknown
variants, or None for all other categories.
Middleware should call this before converting to Problem so
that the real cause can be logged server-side with the trace_id.
The diagnostic is never included in production wire responses.
pub fn gts_type(&self) -> &'static str
pub fn status_code(&self) -> u16
pub fn title(&self) -> &'static str