Field projection support for $select OData queries.
This module provides utilities for projecting DTOs based on selected fields. It allows handlers to filter response objects to only include requested fields.
Functions
- apply_
select - Helper function to apply field projection to a serializable value.
- page_
to_ projected_ json - Convert a page of items to a page of projected JSON values.
- project_
json - Project a JSON value to only include selected fields.