Backend abstraction for out-of-process module management
This module provides traits and types for spawning and managing OoP module instances.
Re-exports
pub use local::LocalProcessBackend;
Modules
- local
- Local process backend implementation
- log_
forwarder - Log forwarding for
OoPmodule stdout/stderr
Structs
- Instance
Handle - A handle to a running module instance
- OopModule
Config - Configuration for an out-of-process module
- OopSpawn
Config - Configuration passed to
OopBackend::spawn
Enums
- Backend
Kind - The kind of backend used to spawn and manage module instances
Traits
- Module
Runtime Backend - Trait for backends that can spawn and manage module instances
- OopBackend
- A type-erased backend for spawning
OoPmodules.