Modules
- shutdown
- Shutdown signal handling utilities
Structs
- Client
Registration - A type-erased client registration for injecting clients into the
ClientHub. - Endpoint
- Represents an endpoint where a module instance can be reached
- Grpc
Installer Data - Grouped installers for all modules in the process.
- Grpc
Installer Store - Runtime-owned store for gRPC service installers.
- Host
Runtime HostRuntimeowns the lifecycle orchestration forModKit.- Module
Installers - Installers for a specific module (module name + service installers).
- Module
Instance - Represents a single instance of a module
- Module
Manager - Central registry that tracks all running module instances in the system. Provides discovery, health tracking, and round-robin load balancing.
- OopModule
Spawn Config - Configuration for a single
OoPmodule to be spawned. - OopSpawn
Options - Options for spawning
OoPmodules. - RunOptions
- Options for running the
ModKitrunner. - System
Context - System-level context provided to system modules during the wiring phase.
Enums
- DbOptions
- How the runtime should provide DBs to modules.
- Instance
State - Shutdown
Options - How the runtime should decide when to stop.
Constants
- MODKIT_
DIRECTORY_ ENDPOINT_ ENV - Environment variable name for passing directory endpoint to
OoPmodules. - MODKIT_
MODULE_ CONFIG_ ENV - Environment variable name for passing rendered module config to
OoPmodules.
Functions
- run
- Full cycle is orchestrated by
HostRuntime(seeruntime/host_runtime.rsdocs).